#-----------------------------------------------------------------------
# Canthology: software that makes it easy to create anthologies.
#
# Copyright (C) 2011 Ciaran McHale.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#----------------------------------------------------------------------

proc usage {}  {
	global argv0

	set msg ""; append msg \
		"usage: tclsh $argv0 -header <file> " \
		"-footer <file> <file(s).html>"
	puts stderr $msg
	exit
}

proc parseCmdLineArgs {_headerFile _footerFile _htmlFileList} {
	global pref argc argv argv0

	upvar $_headerFile	headerFile
	upvar $_footerFile	footerFile 
	upvar $_htmlFileList	htmlFileList

	set headerFile ""
	set footerFile ""
	set htmlFileList {}
	for {set i 0} {$i < $argc} {incr i} {
		set arg   [lindex $argv $i]
		set param [lindex $argv [expr $i + 1]]
		if {$arg == "-header"} {
			set headerFile $param
			incr i
		} elseif {$arg == "-footer"} {
			set footerFile $param
			incr i
		} elseif {[string match "*.html" $arg]} {
			lappend htmlFileList $arg
		} else {
			usage
		}
	}
	if {$headerFile == ""} {
		puts stderr "You must specify -header <file>\n"
		usage
	}
	if {$footerFile == ""} {
		puts stderr "You must specify -footer <file>\n"
		usage
	}
	if {$htmlFileList == ""} {
		puts stderr "You must specify one or more HTML files\n"
		usage
	}
}

proc readFile {fileName} {
	if {[catch {
		set fd [open $fileName "r"]
		set contents [read $fd]
		close $fd
	} err]} {
		puts stderr $err
		exit 1
	}
	return $contents
}

proc writeFile {fileName contents} {
	if {[catch {
		set fd [open $fileName "w"]
		puts -nonewline $fd $contents
		close $fd
	} err]} {
		puts stderr $err
		exit 1
	}
}

proc processHtmlFile {fileName headerText footerText} {
	set contents [readFile $fileName]

	set mapList [list \
		"<body>" "<body>\n$headerText" \
		"<BODY >" "<BODY >\n$headerText" \
		"</body>" "$footerText\n</body>" \
		"</BODY>" "$footerText\n</BODY>" \
	]
	set contents [string map $mapList $contents]

	writeFile $fileName $contents
}

#--------
# Mainline
#--------
parseCmdLineArgs headerFile footerFile htmlFileList


set headerText [readFile $headerFile]
set footerText [readFile $footerFile]

set prog [file tail $argv0]
foreach fileName $htmlFileList {
	#puts "$prog: processing $fileName..."
	processHtmlFile $fileName $headerText $footerText
}
